==> openshift-model-operatorhub-5.2.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ConfigMapResourceReferenceBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigMapResourceReferenceBuilder extends ConfigMapResourceReferenceFluentImpl<ConfigMapResourceReferenceBuilder> implements VisitableBuilder<ConfigMapResourceReference,ConfigMapResourceReferenceBuilder> {

    ConfigMapResourceReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapResourceReferenceBuilder() {
        this(true);
    }

    public ConfigMapResourceReferenceBuilder(Boolean validationEnabled) {
        this(new ConfigMapResourceReference(), validationEnabled);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent) {
        this(fluent, true);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ConfigMapResourceReference(), validationEnabled);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent,ConfigMapResourceReference instance) {
        this(fluent, instance, true);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent,ConfigMapResourceReference instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
        fluent.withName(instance.getName()); 
        fluent.withNamespace(instance.getNamespace()); 
        fluent.withResourceVersion(instance.getResourceVersion()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReference instance) {
        this(instance,true);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReference instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withLastUpdateTime(instance.getLastUpdateTime()); 
        this.withName(instance.getName()); 
        this.withNamespace(instance.getNamespace()); 
        this.withResourceVersion(instance.getResourceVersion()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapResourceReference build() {
        ConfigMapResourceReference buildable = new ConfigMapResourceReference(fluent.getLastUpdateTime(),fluent.getName(),fluent.getNamespace(),fluent.getResourceVersion(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigMapResourceReferenceBuilder that = (ConfigMapResourceReferenceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-operatorhub-5.3.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ConfigMapResourceReferenceBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigMapResourceReferenceBuilder extends ConfigMapResourceReferenceFluentImpl<ConfigMapResourceReferenceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ConfigMapResourceReference,ConfigMapResourceReferenceBuilder> {

    ConfigMapResourceReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapResourceReferenceBuilder() {
        this(true);
    }

    public ConfigMapResourceReferenceBuilder(Boolean validationEnabled) {
        this(new ConfigMapResourceReference(), validationEnabled);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent) {
        this(fluent, true);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ConfigMapResourceReference(), validationEnabled);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent,ConfigMapResourceReference instance) {
        this(fluent, instance, true);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReferenceFluent<?> fluent,ConfigMapResourceReference instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
        fluent.withName(instance.getName()); 
        fluent.withNamespace(instance.getNamespace()); 
        fluent.withResourceVersion(instance.getResourceVersion()); 
        fluent.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReference instance) {
        this(instance,true);
    }

    public ConfigMapResourceReferenceBuilder(ConfigMapResourceReference instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withLastUpdateTime(instance.getLastUpdateTime()); 
        this.withName(instance.getName()); 
        this.withNamespace(instance.getNamespace()); 
        this.withResourceVersion(instance.getResourceVersion()); 
        this.withUid(instance.getUid()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigMapResourceReference build() {
        ConfigMapResourceReference buildable = new ConfigMapResourceReference(fluent.getLastUpdateTime(),fluent.getName(),fluent.getNamespace(),fluent.getResourceVersion(),fluent.getUid());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigMapResourceReferenceBuilder that = (ConfigMapResourceReferenceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
